@@ -59,7 +59,9 @@ void WaylandBackend::setConfig(const KScreen::ConfigPtr &newconfig)
     QEventLoop loop;
 
     connect(m_internalConfig, &WaylandConfig::configChanged, &loop, &QEventLoop::quit);
-    m_internalConfig->applyConfig(newconfig);
+    if (!m_internalConfig->applyConfig(newconfig)) {
+        return;
+    }
 
     loop.exec();
 }
